@@ -16,7 +16,7 @@ lines(agedist)
 print("As you are adding a distribution to an existing plot, make sure xlim and ylim on original plot are set to accomodate all plotted distributions")
 }
 polygon(agedist,col=fillcol)
-if (is(trees,"phylo")) warning("This distribution is based on a single age estimate as only one tree (not a set) was provided")
+if (is(tree,"phylo")) warning("This distribution is based on a single age estimate as only one tree (not a set) was provided")
 }
 if (return.ages==T) {
 if (is(tree,"phylo")) ages[1]
